.. :changelog:

History
-------

0.6.3 (2015-05-21)
++++++++++++++++++

* Added csrf_exempt decorator to helpscout_user view.
* Fixed failing bytes conversion on Python < 3 in helpscout_request decorator.

0.6.2 (2014-12-04)
++++++++++++++++++

* Updated documentation with previously missing configuration option.

0.6.1 (2014-11-20)
++++++++++++++++++

* Fixed bug with Django's HTTP header names (Thanks @Fizzadar!)

0.6.0 (2014-09-29)
++++++++++++++++++

* Preliminary Python 3.4 support.

0.5.0 (2014-08-06)
++++++++++++++++++

* PyPI release.

0.0.1 (2014-08-01)
++++++++++++++++++

* Initial release on GitHub.
